<?php

namespace Ems\Services;

use Ems\Repository\BeneficioRepository;
use Util\Environment;
use Util\NovoCodigo;

class BeneficioService {
    /** @var Environment */
    protected $environment;

    /** @var BeneficioRepository */
    protected $beneficioRepository;

    public function __construct(
        Environment         $environment,
        BeneficioRepository $beneficioRepository
    ) {
        $this->environment          = $environment;
        $this->beneficioRepository  = $beneficioRepository;
    }

    public function setBeneficiario(
        array $row
    ): int {
        $nrOrg = (int) $this->environment->getNrOrg();
        $cdOperador = (string) $this->environment->getCdOperador();
        $params = [];

        $params['NRBENEFICIARIO'] =
            $row['NRBENEFICIARIO'] ??
            NovoCodigo::geraCodigo($nrOrg, 'VAB_BENEFICIARIO', 1, 12, true, false);

        $params['NRORG']                = $row['NRORG'] ?? $nrOrg;
        $params['NRBENEFICIOM']         = (int) $row['NRBENEFICIOM'];
        $params['NRVINCULOM']           = (int) $row['NRVINCULOM'];
        $params['NRPESSOA']             = (int) $row['NRPESSOA'];
        $params['NREVENTOM']            = $row['NREVENTOM'] ?? null;
        $params['NRINTEGTRANSPM']       = $row['NRINTEGTRANSPM'] ?? null;
        $params['NRVALORREFERENCIAM']   = $row['NRVALORREFERENCIAM'] ?? null;
        $params['NRVINCEVENTO']         = $row['NRVINCEVENTO'] ?? null;
        $params['DTINSCBENEFICIARIO']   = (string) $row['DTINSCBENEFICIARIO'];
        $params['NRINSCBENEFICIARIO']   = $row['NRINSCBENEFICIARIO'] ?? null;
        $params['DTCANCBENEFICIARIO']   = $row['DTCANCBENEFICIARIO'] ?? null;
        $params['QTBENEFICIO']          = (int) $row['QTBENEFICIO'];
        $params['VRBENEFICIO']          = $row['VRBENEFICIO'] ?? null;
        $params['IDTPBENEFICIARIO']     = $row['IDTPBENEFICIARIO'] ?? null;
        $params['IDVALORDIFEBENEF']     = $row['IDVALORDIFEBENEF'] ?? null;
        $params['DSOBSBENEFICIARIO']    = $row['DSOBSBENEFICIARIO'] ?? null;
        $params['IDATIVO']              = $row['IDATIVO'] ?? 'S';
        $params['NRORGINCLUSAO']        = $row['NRORGINCLUSAO'] ?? $nrOrg;
        $params['DTINCLUSAO']           = $row['DTINCLUSAO'] ?? date('d/m/Y');
        $params['CDOPERINCLUSAO']       = $row['CDOPERINCLUSAO'] ?? $cdOperador;
        $params['NRORGULTATU']          = $row['NRORGULTATU'] ?? null;
        $params['DTULTATU']             = $row['DTULTATU'] ?? null;
        $params['CDOPERULTATU']         = $row['CDOPERULTATU'] ?? null;
        $params['SUBSIDIO100']          = $row['SUBSIDIO100'] ?? 'N';
        $params['VRPERCSUBSIDIO']       = $row['VRPERCSUBSIDIO'] ?? null;

        $this->beneficioRepository->setBeneficiario($params);

        return $params['NRBENEFICIARIO'];
    }

    public function getBeneficio(
        int $nrBeneficio
    ) {
        $nrOrg = (int) $this->environment->getNrOrg();

        $beneficio = $this->beneficioRepository->getBeneficio($nrOrg, $nrBeneficio);

        return $beneficio;
    }
}